@@ -1,9 +1,24 @@
+from aiofiles import open as async_open
 from orjson import dumps as odumps, loads as oloads
 from typing import Union as Union
 
 
 # Json operate
 
+async def async_read_json(path: str):
+    """Async read json file with orjson."""
+
+    async with async_open(path, 'rb') as f:
+        return oloads(await f.read())
+
+
+async def async_save_json(path: str, data: Union[dict, list]):
+    """Async save json file with orjson."""
+
+    async with async_open(path, 'wb') as f:
+        return await f.write(odumps(data))
+
+
 def read_json(path: str):
     """Read json file with orjson."""
 
@@ -16,19 +31,3 @@ def save_json(path: str, data: Union[dict, list]):
 
     with open(path, 'wb') as f:
         return f.write(odumps(data))
-
-
-# List
-
-def add_item_to_list(_list: list, item):
-    """Add item to list if item not in list."""
-
-    if item not in _list:
-        _list.append(item)
-
-
-def remove_list_item(_list: list, item):
-    """Remove list item."""
-
-    if item in _list:
-        _list.remove(item)
